@@ -87,7 +87,15 @@ Let's say we wanted to expand our greeting to add some punctuation at the end:
 
 How does this work?  Follow the pipeline in the direction of the E<lt>E<lt>...
 First we prepend 'Ciao ' to get 'Ciao Bella', then we pass that to the curry that
-appends '!'.
+appends '!'.  We can also write them in the opposite order, to match evaluation
+order, by reversing the operator:
+
+    my $ciao = prepend('Ciao ') >> append('!');
+    say $ciao->('Bella'); # Ciao Bella!
+
+Finally, we can create a shell-like pipeline:
+
+    say 'Bella' | prepend('Ciao ') | append('!'); # Ciao Bella!
 
 The overloaded syntax is provided by C<Sub::Composable> which is distributed with 
 this module as a base class.
@@ -105,7 +113,7 @@ use Sub::Current;
 use B::Hooks::EndOfScope;
 use Devel::BeginLift;
 
-our $VERSION = '0.11';
+our $VERSION = '0.13';
 
 # cargo culted
 sub import {
@@ -317,7 +325,21 @@ to declare how many arguments it's expecting)
 
 =head1 AUTHOR and LICENSE
 
- (c)2008-2009 osfameron@cpan.org
+ (c)2008-2013 osfameron@cpan.org
+
+=head2 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Florian (rafl) Ragwitz
+
+=item *
+
+Paul (prj) Jarc
+
+=back
 
 This module is distributed under the same terms and conditions as Perl itself.
 
